imager

package
v1.7.6-0...-a17e0fe Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2016 License: MIT Imports: 10 Imported by: 0

Documentation

Overview

Package imager handles image, video, etc. upload requests and processing.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewImageUpload

func NewImageUpload(res http.ResponseWriter, req *http.Request)

NewImageUpload handles the clients' image (or other file) upload request

Types

type ProtoImage

type ProtoImage struct {
	types.Image
	ClientID string
	// contains filtered or unexported fields
}

ProtoImage stores data of an image that is being processed as well as data, that will be stored, once the image finishes processing.

Jump to