Documentation
¶
Overview ¶
Package imager handles image, video, etc. upload requests and processing.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewImageUpload ¶
func NewImageUpload(res http.ResponseWriter, req *http.Request)
NewImageUpload handles the clients' image (or other file) upload request
Types ¶
type ProtoImage ¶
ProtoImage stores data of an image that is being processed as well as data, that will be stored, once the image finishes processing.
Click to show internal directories.
Click to hide internal directories.